@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@codefactory.se>
+ * Author: Mikael Hallendal <micke@imendio.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -74,9 +74,13 @@ static void content_insert_tree               (YelpViewContent      *content,
 static void content_set_tree                  (YelpViewContent      *content, 
 					       GNode                *node);
 static void
-content_show_uri                             (YelpView              *view, 
-					      YelpURI               *uri,
-					      GError               **error);
+content_show_uri                              (YelpView              *view, 
+					       YelpURI               *uri,
+					       GError               **error);
+
+static YelpHtml *
+content_get_html                              (YelpView              *view);
+
 
 struct _YelpViewContentPriv {
 	GtkWidget    *hpaned;
@@ -176,6 +180,7 @@ content_class_init (YelpViewContentClass *klass)
 	YelpViewClass *view_class = YELP_VIEW_CLASS (klass);
        
 	view_class->show_uri = content_show_uri;
+	view_class->get_html = content_get_html;
 }
 
 static void
@@ -278,30 +283,23 @@ content_reader_finished_cb (YelpReader      *reader,
 	if (path) {
 		GtkTreeSelection *selection;
 		GtkTreePath      *parent;
-
+		gint              i, depth;
+		
 		/* Open the correct node in the tree */
 
 		d(g_print ("Found path\n"));
 		
 		selection = gtk_tree_view_get_selection (
 			GTK_TREE_VIEW (priv->content_tree));
-			
- 		parent = gtk_tree_path_copy (path);
 		
-		gtk_tree_path_up (parent);
-
-		gtk_tree_view_expand_row (GTK_TREE_VIEW (priv->content_tree),
- 					  parent, FALSE);
-
-		gtk_tree_view_expand_row (GTK_TREE_VIEW (priv->content_tree),
- 					  path, TRUE);
-
+		gtk_tree_view_expand_to_path (GTK_TREE_VIEW (priv->content_tree),
+					      path);
+		
 		g_signal_handlers_block_by_func (
 			selection,
 			(gpointer) content_tree_selection_changed_cb,
 			view);
  
-/* 		gtk_tree_selection_select_path (selection, path); */
 		gtk_tree_view_set_cursor (GTK_TREE_VIEW (priv->content_tree),
 					  path, NULL, FALSE);
 		
@@ -309,16 +307,8 @@ content_reader_finished_cb (YelpReader      *reader,
 			selection,
 			(gpointer) content_tree_selection_changed_cb,
 			view);
-
-		while (gtk_tree_path_up (path)) {
-			gtk_tree_view_expand_row (
-				GTK_TREE_VIEW (priv->content_tree),
-				path, FALSE);
-		}
-
+		
 		gtk_tree_path_free (path);
-		gtk_tree_path_free (parent);
-
 	} else {
 		gtk_widget_grab_focus (priv->html_widget);
 	}
@@ -474,7 +464,7 @@ content_show_uri (YelpView *view, YelpURI *uri, GError **error)
 	}
 
 	if (reset_focus) {
-		gtk_widget_child_focus (GTK_WIDGET (view),
+		gtk_widget_child_focus (GTK_WIDGET (view->widget),
 					GTK_DIR_TAB_FORWARD);
 	}
 	
@@ -497,10 +487,15 @@ content_show_uri (YelpView *view, YelpURI *uri, GError **error)
 		gchar     *loading = _("Loading...");
 
 		yelp_html_clear (priv->html_view);
-
+		
 		yelp_html_printf (priv->html_view, 
-				  "<html><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><title>..</title><body><center>%s</center></body></html>", 
-				  loading);
+				  "<html><head><meta http-equiv=\"Content-Type\" "
+				  "content=\"text/html; charset=utf-8\">"
+				  "<title>%s</title></head>"
+				  "<body><center>%s</center></body>"
+				  "</html>", 
+				  loading, loading);
+
 		yelp_html_close (priv->html_view);
 	}
 }
@@ -563,3 +558,16 @@ yelp_view_content_new (GNode *doc_tree)
 	return YELP_VIEW (view);
 }
 
+static YelpHtml *
+content_get_html (YelpView *view)
+{
+	YelpViewContent     *content;
+	YelpViewContentPriv *priv;
+	
+	g_return_val_if_fail (YELP_IS_VIEW_CONTENT (view), NULL);
+
+	content = YELP_VIEW_CONTENT (view);
+	priv = content->priv;
+		
+	return YELP_HTML (priv->html_view);
+}
